==> v1.4.1.tar.gz: logstash/docs/learn.md <==
---
title: Learn - logstash
layout: content_right
---
# What is logstash?

logstash is a tool for managing your logs.

It helps you take logs and other event data from your systems and move it into
a central place. logstash is open source and completely free. You can find
support on the mailing list and on IRC.

For an overview of logstash and why you would use it, you should watch the
presentation I gave at CarolinaCon 2011: 
[video here](http://carolinacon.blip.tv/file/5105901/). This presentation covers
logstash, how you can use it, some alternatives, logging best practices,
parsing tools, etc. Video also below:

<!--
<embed src="http://blip.tv/play/gvE9grjcdQI" type="application/x-shockwave-flash" width="480" height="296" allowscriptaccess="always" allowfullscreen="true"></embed>

The slides are available online here: [slides](http://goo.gl/68c62). The slides
include speaker notes (click 'actions' then 'speaker notes').
-->
<iframe width="480" height="296" src="http://www.youtube.com/embed/RuUFnog29M4" frameborder="0" allowfullscreen="allowfullscreen"></iframe>

The slides are available online here: [slides](http://semicomplete.com/presentations/logstash-puppetconf-2012/).

## Getting Help

There's [documentation](.) here on this site. If that isn't sufficient, you can
email the mailing list (logstash-users@googlegroups.com). Further, there is also
an IRC channel - #logstash on irc.freenode.org.

If you find a bug or have a feature request, file them
on <http://logstash.jira.com/>. (Honestly though, if you prefer email or irc
for such things, that works for me, too.)

## Download It

[Download logstash-%VERSION%](https://download.elasticsearch.org/logstash/logstash/logstash-%VERSION%.tar.gz)

## What's next?

Try this [guide](tutorials/getting-started-with-logstash) for a simple
real-world example getting started using logstash.

==> v1.5.0.rc1.tar.gz: logstash/docs/learn.md <==
---
title: Learn - logstash
layout: content_right
---
# What is logstash?

logstash is a tool for managing your logs.

It helps you take logs and other event data from your systems and move it into
a central place. logstash is open source and completely free. You can find
support on the mailing list and on IRC.

For an overview of logstash and why you would use it, you should watch the
presentation I gave at CarolinaCon 2011: 
[video here](http://carolinacon.blip.tv/file/5105901/). This presentation covers
logstash, how you can use it, some alternatives, logging best practices,
parsing tools, etc. Video also below:

<!--
<embed src="http://blip.tv/play/gvE9grjcdQI" type="application/x-shockwave-flash" width="480" height="296" allowscriptaccess="always" allowfullscreen="true"></embed>

The slides are available online here: [slides](http://goo.gl/68c62). The slides
include speaker notes (click 'actions' then 'speaker notes').
-->
<iframe width="480" height="296" src="http://www.youtube.com/embed/RuUFnog29M4" frameborder="0" allowfullscreen="allowfullscreen"></iframe>

The slides are available online here: [slides](http://semicomplete.com/presentations/logstash-puppetconf-2012/).

## Getting Help

There's [documentation](.) here on this site. If that isn't sufficient, you can
email the mailing list (logstash-users@googlegroups.com). Further, there is also
an IRC channel - #logstash on irc.freenode.org.

If you find a bug or have a feature request, file them
on [github](https://github.com/elasticsearch/logstas/issues). (Honestly though, if you prefer email or irc
for such things, that works for me, too.)

## Download It

[Download logstash-%VERSION%](https://download.elasticsearch.org/logstash/logstash/logstash-%VERSION%.tar.gz)

## What's next?

Try this [guide](tutorials/getting-started-with-logstash) for a simple
real-world example getting started using logstash.
